mailr9708 - /branches/bmrb/generic_fns/bmrb_saveframes.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on October 09, 2009 - 18:49:
Author: bugman
Date: Fri Oct  9 18:49:25 2009
New Revision: 9708

URL: http://svn.gna.org/viewcvs/relax?rev=9708&view=rev
Log:
The SVN repository URL is now sent into the Software saveframe.


Modified:
    branches/bmrb/generic_fns/bmrb_saveframes.py

Modified: branches/bmrb/generic_fns/bmrb_saveframes.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/bmrb/generic_fns/bmrb_saveframes.py?rev=9708&r1=9707&r2=9708&view=diff
==============================================================================
--- branches/bmrb/generic_fns/bmrb_saveframes.py (original)
+++ branches/bmrb/generic_fns/bmrb_saveframes.py Fri Oct  9 18:49:25 2009
@@ -24,7 +24,7 @@
 """Module containing read/write functions for miscellaneous BMRB NMR-STAR 
saveframes."""
 
 # relax module imports.
-from version import version, get_revision
+from version import version, get_revision, get_url
 
 
 def write_relax(star):
@@ -37,12 +37,15 @@
     # The relax version.
     ver = version
     if ver == 'repository checkout':
         # Get the SVN revision.
         rev = get_revision()
+        url = get_url()
 
         # Change the version string.
         if rev:
             ver = version + " r" + rev
+        if url:
+            ver = ver + " " + url
 
     # The relax info.
     star.software.add(name='relax', version=ver, vendor_name='The relax 
@@ -37,12 +37,15 @@
     ver = version
     if ver == 'repository checkout':
-        # Get the SVN revision.
+        # Get the SVN revision and URL.
         rev = get_revision()
development team', vendor_eaddress='http://nmr-relax.com', task='data 
processing')




Related Messages


Powered by MHonArc, Updated Fri Oct 09 20:20:05 2009